@@ -31,7 +31,7 @@ function(hljs) {
 
   var NUMBERS = {
     className: 'number',
-    begin: /0\'\\.|0\'.|0b[0-1]+|0o[0-7]+|0x[0-9a-fA-F]+|[0-9]+(\.[0-9]+)?([eE]([-+])?[0-9]+)?/,
+    begin: /0\'[\\]?.|0b[0-1]+|0o[0-7]+|0x[0-9a-fA-F]+|[0-9]+(\.[0-9]+)?([eE]([-+])?[0-9]+)?/,
     relevance: 0
   };
 
