@@ -2,11 +2,11 @@
 
 #############################################################################
 ## 
-##   Set CLASSPATH environment variable for LVM
-##   Last updated on July 21, 2023
+##   Set CLASSPATH environment variable
+##   Last updated on June 19, 2024
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
+##   SPDX-FileCopyrightText: 1998-2024 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
 #############################################################################
 
 
-NEO4J="$(neo4j --verbose status | grep 'app.home' | sed 's/.*-Dapp.home=\(.*\),.*/\1/')"
+NEO4J="$(neo4j status --verbose | grep 'app.home' | sed 's/.*-Dapp.home=\(.*\),.*/\1/')"
 
 for jar in "$NEO4J"/lib/*.jar; do
 	CLASSPATH="$jar":$CLASSPATH
