@@ -4,10 +4,10 @@
 ## 
 ##   Logtalk script for updating the HTML library and tools SVG diagrams
 ## 
-##   Last updated on December 25, 2023
+##   Last updated on November 2, 2024
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
+##   SPDX-FileCopyrightText: 1998-2024 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
@@ -44,7 +44,6 @@ fi
 
 # default to SWI-Prolog as the backend compiler
 backend=swi
-prolog='SWI-Prolog'
 logtalk="swilgt$extension -g"
 include_packs='false'
 if [ "$LOGTALKPACKS" != "" ] ; then
@@ -75,7 +74,7 @@ set_goals() {
 }
 
 print_version() {
-	echo "$(basename "$0") 0.25"
+	echo "$(basename "$0") 0.26"
 	exit 0
 }
 
@@ -117,43 +116,30 @@ if [ "$p_arg" == "b" ] ; then
 	prolog='B-Prolog'
 	logtalk="bplgt$extension -g"
 elif [ "$p_arg" == "ciao" ] ; then
-	prolog='Ciao Prolog'
 	logtalk="ciaolgt$extension -e"
 elif [ "$p_arg" == "cx" ] ; then
-	prolog='CxProlog'
 	logtalk="cxlgt$extension --goal"
 elif [ "$p_arg" == "eclipse" ] ; then
-	prolog='ECLiPSe'
 	logtalk="eclipselgt$extension -e"
 elif [ "$p_arg" == "gnu" ] ; then
-	prolog='GNU Prolog'
 	logtalk="gplgt$extension --query-goal"
 elif [ "$p_arg" == "ji" ] ; then
-	prolog='JIProlog'
 	logtalk="jiplgt$extension -n -g"
 elif [ "$p_arg" == "xvm" ] ; then
-	prolog='XVM'
 	logtalk="xvmlgt$extension -g"
 elif [ "$p_arg" == "sicstus" ] ; then
-	prolog='SICStus Prolog'
 	logtalk="sicstuslgt$extension --goal"
 elif [ "$p_arg" == "swi" ] ; then
-	prolog='SWI-Prolog'
 	logtalk="swilgt$extension -g"
 elif [ "$p_arg" == "swipack" ] ; then
-	prolog='SWI-Prolog'
 	logtalk="swipl -g"
 elif [ "$p_arg" == "tau" ] ; then
-	prolog='Tau Prolog'
 	logtalk="taulgt$extension -g"
 elif [ "$p_arg" == "trealla" ] ; then
-	prolog='Trealla Prolog'
 	logtalk="tplgt$extension -g"
 elif [ "$p_arg" == "xsb" ] ; then
-	prolog='XSB'
 	logtalk="xsblgt$extension -e"
 elif [ "$p_arg" == "yap" ] ; then
-	prolog='YAP'
 	logtalk="yaplgt$extension -g"
 elif [ "$p_arg" != "" ] ; then
 	echo "Error! Unsupported backend Prolog compiler: $p_arg" >&2
